{%- if not nav_item.children %}
<li>
    <a href="{{ nav_item.url|url }}" class="{% if nav_item.active %} active{% endif %}">{{ nav_item.title }}</a>
</li>
{%- else %}
<li>
  <span>{{ nav_item.title }}</span>
  <!--<a href="#" class="">{{ nav_item.title }}</a>-->
  <ul>
    {%- for nav_item in nav_item.children %}
    {% include "nav-sub.html" %}
    {%- endfor %}
  </ul>
</li>
{%- endif %}
