<nav id="mainnav" class="navbar navbar-default navbar-expand-md navbar-light sticky-top" role="navigation">
  
    {%- block site_name %}
    <a class="navbar-brand" href="{{ nav.homepage.url|url }}">
      {{ config.site_name }}
    </a>
    {%- endblock %}
    <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#mainnav-navbar-collapse" aria-controls="mainnav-navbar-collapse" aria-expanded="false" aria-label="Toggle navigation">
      <span class="navbar-toggler-icon"></span>
    </button>
    <div id="mainnav-navbar-collapse" class="collapse navbar-collapse">
      {%- block site_nav %}
      <ul class="nav navbar-nav mr-auto mx-auto">
        <li class="main-item">
          <a class="nav-link" href="#">Link 1</a>
        </li>
        <li class="main-item">
          <a class="nav-link" href="#">Link 2</a>
        </li>
        <li class="main-item">
          <a class="nav-link" href="#">Link 3</a>
        </li>
      </ul>
      {%- endblock %}
      
      <ul class="navbar-nav flex-row ml-md-auto d-none d-md-flex">
        {%- block search_button %}
        {%- if 'search' in config['plugins'] %}
        <li class="nav-item">
          <a class="nav-link" href="#" data-toggle="modal" data-target="#mkdocs_search_modal">
	    <i class="fa fa-search"></i> Search
          </a>
        </li>
        {%- endif %}
        {%- endblock %}
	
        {%- block next_prev %}
        {%- if page and (page.next_page or page.previous_page) and (not config.theme.suppress_nextprev) %}
        <li class="nav-item{% if not page.previous_page %} disabled{% endif %}">
          <a class="nav-link" rel="next" {% if page.previous_page %}href="{{ page.previous_page.url|url }}"{% endif %}>
	    <i class="fa fa-arrow-left"></i> Previous
          </a>
        </li>
        <li class="nav-item{% if not page.next_page %} disabled{% endif %}">
          <a class="nav-link" rel="prev" {% if page.next_page %}href="{{ page.next_page.url|url }}"{% endif %}>
	    Next <i class="fa fa-arrow-right"></i>
          </a>
        </li>
        {%- endif %}
        {%- endblock %}
	
        {%- block repo %}
        {%- if page and page.edit_url %}
        <li class="nav-item">
          <a class="nav-link" href="{{ page.edit_url }}">
	    {%- if config.repo_name == 'GitHub' -%}
	    <i class="fa fa-github"></i> Edit on {{ config.repo_name }}
	    {%- elif config.repo_name == 'Bitbucket' -%}
	    <i class="fa fa-bitbucket"></i> Edit on {{ config.repo_name }}
	    {%- elif config.repo_name == 'GitLab' -%}
	    <i class="fa fa-gitlab"></i> Edit on {{ config.repo_name }}
	    {%- else -%}
	    Edit on {{ config.repo_name }}
	    {%- endif -%}
          </a>
        </li>
        {%- elif config.repo_url %}
        <li class="nav-item">
          <a class="nav-link" href="{{ config.repo_url }}">
	    {%- if config.repo_name == 'GitHub' -%}
	    <i class="fa fa-github"></i> {{ config.repo_name }}
	    {%- elif config.repo_name == 'Bitbucket' -%}
	    <i class="fa fa-bitbucket"></i> {{ config.repo_name }}
	    {%- elif config.repo_name == 'GitLab' -%}
	    <i class="fa fa-gitlab"></i> {{ config.repo_name }}
	    {%- else -%}
	    {{ config.repo_name }}
	    {%- endif -%}
          </a>
        </li>
        {%- endif %}
        {%- endblock %}
      </ul>
    </div>
</nav>
