<footer class="col-md-12">
  {%- block footer %}
  <nav class="container">
    <div class="row">
      <div class="col-12">
	<ul class="nav flex-row ml-md-auto d-none d-md-flex pull-right">
	  <li class="nav-item"><a class="nav-link" href="#">License</a></li>
	  <li class="nav-item"><a class="nav-link" href="#">GitHub Home</a></li>
	</ul>
      </div>
    </div>
    <div class="row">
      <div class="col-6">
	{%- if config.copyright %}
	<p>&copy;{{ config.copyright }}</p>
	{%- endif %}
      </div>
      <div class="col-6">
	<ul class="nav flex-row ml-md-auto d-none d-md-flex pull-right">
	  <li><a class="nav-link footer-image-link footer-image-link-facebook" href="#">
	      <i class="fa fa-facebook"></i></a></li>
	  <li><a class="nav-link footer-image-link footer-image-link-twitter" href="#">
	      <i class="fa fa-twitter"></i></a></li>
	  <li><a class="nav-link footer-image-link footer-image-link-linkedin" href="#">
	      <i class="fa fa-linkedin"></i></a></li>
	  <li><a class="nav-link footer-image-link footer-image-link-youtube" href="#">
	      <i class="fa fa-youtube"></i></a></li>
	</ul>
      </div>
  </nav>
  {%- endblock %}
</footer>
